import { Switch, Route } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { ScrollProgress } from "@/components/ui/ScrollProgress";
import { BackToTop } from "@/components/ui/BackToTop";
import { LoadingSpinner } from "@/components/ui/LoadingSpinner";
import { FastPageLoader } from "@/components/performance/FastPageLoader";
import { useScrollToTop } from "@/hooks/useScrollToTop";
import { useState, useEffect, lazy, Suspense } from "react";
import { useLocation } from "wouter";
import SiteHeader from "@/components/ui/SiteHeader";
import SiteFooter from "@/components/ui/SiteFooter";
import ScrollToTop from "@/components/ui/ScrollToTop";

import { motion, AnimatePresence } from "framer-motion";
import { usePreloadImages } from "@/hooks/usePreloadImages";
import { useOptimizedScroll } from "@/hooks/useOptimizedScroll";
import { useSEOAnalytics } from "@/hooks/use-seo-analytics";
import { PerformanceTracker } from "@/components/seo/PerformanceTracker";
import { CriticalCSS } from "@/components/performance/CriticalCSS";
import { ResourcePreloader } from "@/components/performance/ResourcePreloader";
import { WebVitalsOptimizer } from "@/components/performance/WebVitalsOptimizer";
import { CriticalResourceLoader } from "@/components/performance/CriticalResourceLoader";
import { MobileOptimizer } from "@/components/performance/MobileOptimizer";
import { SmoothExperience } from "@/components/performance/SmoothExperience";

// Critical pages loaded immediately for better UX
import HomePage from "@/pages/HomePage";

// Load problematic pages immediately to fix loading issues
import ContactPage from "@/pages/ContactPage";
import ResourcesPage from "@/pages/ResourcesPage";
import AdvancedAIPage from "@/pages/AdvancedAIPage";

// Other pages lazy loaded for better performance
const LazyAboutPage = lazy(() => import("@/pages/AboutPage"));
const LazyServicesPage = lazy(() => import("@/pages/ServicesPage"));
const LazyPricingPage = lazy(() => import("@/pages/PricingPage"));
const LazyResourceDetailPage = lazy(() => import("@/pages/ResourceDetailPage"));
const LazyToolsPage = lazy(() => import("@/pages/ToolsPage"));
const LazyToolDetailPage = lazy(() => import("@/pages/ToolDetailPage"));
const LazyPrivacyPage = lazy(() => import("@/pages/PrivacyPage"));
const LazyTermsPage = lazy(() => import("@/pages/TermsPage"));
const LazyCookiesPage = lazy(() => import("@/pages/CookiesPage"));
const LazySitemapPage = lazy(() => import("@/pages/SitemapPage"));
const LazyNotFoundPage = lazy(() => import("@/pages/not-found"));

// Optimized loading component for better LCP
const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center bg-gray-50">
    <div className="text-center">
      <div className="w-8 h-8 border-2 border-gray-200 border-t-blue-600 rounded-full animate-spin"></div>
      <p className="text-gray-600 text-sm mt-2">Loading...</p>
    </div>
  </div>
);

function PageTransition({ children }: { children: React.ReactNode }) {
  const [location] = useLocation();
  const [isTransitioning, setIsTransitioning] = useState(false);

  useEffect(() => {
    setIsTransitioning(true);
    
    // Smooth scroll to top with optimized timing
    const scrollToTop = () => {
      if (window.scrollY > 0) {
        window.scrollTo({ 
          top: 0, 
          behavior: 'smooth' 
        });
      }
    };
    
    // Delay scroll to allow page transition to start
    const timeoutId = setTimeout(() => {
      scrollToTop();
      setIsTransitioning(false);
    }, 100);

    return () => clearTimeout(timeoutId);
  }, [location]);

  return (
    <AnimatePresence mode="wait">
      <motion.div
        key={location}
        initial={{ 
          opacity: 0,
          y: 10
        }}
        animate={{ 
          opacity: 1,
          y: 0
        }}
        exit={{ 
          opacity: 0,
          y: -10
        }}
        transition={{ 
          duration: 0.3,
          ease: [0.4, 0, 0.2, 1],
          type: "tween"
        }}
        className="gpu-accelerated"
        style={{
          transform: 'translateZ(0)',
          willChange: 'transform, opacity'
        }}
      >
        {children}
      </motion.div>
    </AnimatePresence>
  );
}

function Router() {
  // Track page views and analytics
  useSEOAnalytics();

  return (
    <div className="flex flex-col min-h-screen min-h-[100dvh] w-full">
      <PerformanceTracker />
      <SiteHeader />
      <main className="flex-grow w-full">
        <PageTransition>
          <Suspense fallback={<FastPageLoader />}>
            <Switch>
              <Route path="/" component={HomePage} />
              <Route path="/about" component={LazyAboutPage} />
              <Route path="/services" component={LazyServicesPage} />
              <Route path="/tools" component={LazyToolsPage} />
              <Route path="/tools/:id" component={LazyToolDetailPage} />
              <Route path="/advanced-ai" component={AdvancedAIPage} />
              <Route path="/resources" component={ResourcesPage} />
              <Route path="/resources/:id" component={LazyResourceDetailPage} />
              <Route path="/pricing" component={LazyPricingPage} />
              <Route path="/contact" component={ContactPage} />
              <Route path="/privacy" component={LazyPrivacyPage} />
              <Route path="/terms" component={LazyTermsPage} />
              <Route path="/cookies" component={LazyCookiesPage} />
              <Route path="/sitemap" component={LazySitemapPage} />
              <Route component={LazyNotFoundPage} />
            </Switch>
          </Suspense>
        </PageTransition>
      </main>
      <SiteFooter />
    </div>
  );
}

function App() {
  const { scrollDirection, isScrolling } = useOptimizedScroll();
  
  // Preload critical images for better performance
  usePreloadImages([
    '/assets/company-logo.png',
    '/assets/logo.svg'
  ]);

  useEffect(() => {
    // Hide initial loader with smooth animation
    const loader = document.getElementById('initial-loader');
    if (loader) {
      loader.style.opacity = '0';
      loader.style.transition = 'opacity 0.3s ease-out';
      setTimeout(() => {
        loader.classList.add('hidden');
        setTimeout(() => loader.remove(), 100);
      }, 300);
    }

    // Enable GPU acceleration for smooth interactions
    document.body.classList.add('gpu-accelerated', 'smooth-scroll');
    
    // Optimize scroll performance
    document.documentElement.style.scrollBehavior = 'smooth';
    document.documentElement.style.setProperty('--animation-duration', '0.3s');
  }, []);

  // Initialize SEO analytics
  useSEOAnalytics();

  return (
    <QueryClientProvider client={queryClient}>
      <TooltipProvider>
        <ScrollProgress />
        <BackToTop />
        <Toaster />
        <Router />
      </TooltipProvider>
    </QueryClientProvider>
  );
}

export default App;